@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20130430';
+our $VERSION = '0.20130531';
 
-# Table last modified: 2013-04-30
+# Table last modified: 2013-05-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -14,7 +14,7 @@ our %ZIP_TABLE = (
     '005' => '(?:8(?:5(?:[58]5|01|43)|6(?:12|0[12])|798))',
     '006' => '(?:8(?:5(?:[23]0|[58]5|61)|612))',
     '007' => '(?:8(?:5(?:85|0[13578])|632))',
-    '010' => '(?:(?:8(?:5(?:43|3[03]|6[04-6]|2[025]|1[158]|[58][058]|0[124-7]|7[0247])|6(?:[01]1|33|55|68|7[78]|2[12])|794)|0(?:49[2-4]|[15]95)|1(?:49[2-4]|292)))',
+    '010' => '(?:(?:8(?:5(?:43|3[03]|2[025]|1[158]|6[045]|[58][058]|0[124-7]|7[0247])|6(?:[01]1|33|55|68|7[78]|2[12])|794)|0(?:49[2-4]|[15]95)|1(?:49[2-4]|292)))',
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
     '013' => '(?:(?:8(?:5(?:92|0[1-4])|6(?:10|0[129]))|0498))',
@@ -103,98 +103,98 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|5[018]|0[2358]|4[0149]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|4[158]|2[1245]|3[138]|0[237]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[035])|101))',
-    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[245]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|8[2457]|7[02358]|3[0-8]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-25-8]|1[14-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|8[0368]|7[027]|2[014589]|5[167]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[015-9]|6[01457]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
-    '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
-    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|0[357]|8[0134689]|7[0-37-9]|5[0158]|2[0235689]|4[15]|3[013489]|6[016])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|8[02]|0[1-38]|3[0-4]|5[05]|1[017]|[24][0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[126-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[1589])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
+    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[035])|101))',
+    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[45]|1[125689])|79[58]))',
+    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|8[2457]|7[02358]|3[0-8]|2[124589]|5[0-2589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|6[067]|3[13-8]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-8])|4(?:3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|1[05689]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:4[04]|1[0-3579]|8[0368]|7[027]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|7[0-39]|4[015-9]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:0[127]|1[1267]))|7444))',
+    '106' => '(?:(?:8(?:5(?:08|3[0-257]|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
+    '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[079]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
+    '108' => '(?:(?:8(?:5(?:1[025]|7[1358]|4[03-578]|3[0236]|0[12579]|5[0-36-9]|6[48]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|0[357]|8[0134689]|1[35]|6[01]|4[15]|7[02389])|2(?:7[056]|1[17]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2])|4(?:[56]6|85|0[347]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|2[28]|1[0-256]|4[0-268])|0(?:[258]0|[17]1|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
-    '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[0158]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
+    '110' => '(?:8(?:5(?:8[2-468]|6[0-25-7]|5[0589]|4[013689]|7[5-8]|3[0-4679]|0[1-3579]|1[01357]|2[0-24])|6(?:97|2[0-2568]|6[0259]|5[34]|4[245]|3[0158]|0[259]|8[015-7]|1[03-589]|7[35-8])|7(?:45|8[027]|1[2-6]|3[36]|0[68]|2[1-35])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
-    '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|1[02-57-9]|7[147]|2[0-2468]|5[02-57]|3[0-24589])|6(?:11|86|0[2-6])))',
+    '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|7[147]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-26]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
     '120' => '(?:8(?:5(?:44|81|7[057]|0[178]|1[02]|2[068]|3[0469]|5[03568])|60[12]))',
-    '121' => '(?:8(?:5(?:33|40|1[015]|0[245]|2[0-4]|8[58]|5[05])|6(?:[02]1|3[39]|8[0-2]|1[016])|7(?:01|29|1[01])|080))',
-    '123' => '(?:85(?:40|8[58]|1[147]|0[135689]))',
+    '121' => '(?:8(?:5(?:20|0[45]|8[58]|[15][05])|6(?:82|3[39]|1[01])|7(?:11|29)|080))',
+    '123' => '(?:85(?:40|88|1[147]|0[135689]))',
     '124' => '(?:85(?:60|77|2[04]|3[3589]|0[1-39]|8[58]|5[05]|1[01]))',
     '125' => '(?:8(?:5(?:55|1[1-57]|0[3-8]|8[58]|2[026])|601))',
-    '130' => '(?:8(?:5(?:7[057]|8[0348]|3[013-589]|4[358]|6[15-7]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|0[1-589]|7[17]|3[67]|5[05]|6[068]|1[15]|4[024])|7(?:[12]0|0[16])))',
+    '130' => '(?:8(?:5(?:7[057]|8[0348]|3[013-589]|4[358]|6[15-7]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|7[17]|3[67]|5[05]|6[068]|1[15]|0[1-689]|4[024])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-9])|634|711))',
-    '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
+    '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-3])|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-3])|080))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
-    '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:2[01379]|3[0137-9]|4[02-46-8]|0[2-6]|7[0-36]|8[01346-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|6[0-25-8]|5[05-79]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
-    '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
-    '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
-    '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[14]|6[01])))',
-    '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
+    '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|7[1-36]|3[013689]|6[0367]|2[013569]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
+    '141' => '(?:8(?:6(?:7[1-3]|2[01379]|3[0137-9]|6[045]|4[02-46-8]|0[2-6]|8[048]|1[01356]|5[06-8])|5(?:34|4[04]|0[13-578]|5[59]|2[0-25]|1[02579]|6[0-25-8]|8[0248]|7[267])|4(?:2[0-3]|1[1-9])|7(?:0[17]|1[05])|001))',
+    '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)))',
+    '143' => '(?:85(?:28|70|5[02578]|3[13589]|0[24578]|8[05]|6[0578]|4[014]|1[145]))',
+    '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|11|2[1-3]|5[056]|7[78]|6[01])))',
+    '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
-    '150' => '(?:8(?:5(?:45|8[5-7]|2[25]|6[379]|5[05]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|6[37]|2[25]|5[05]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:7[1-7]|0[01])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|6[05-8]|2[0135]|3[0-369]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
-    '156' => '(?:8(?:5(?:22|33|55|0[1246]|8[58]|1[01])|666))',
+    '156' => '(?:8(?:5(?:22|33|55|88|0[246]|1[01])|666))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:1[0-259]|4[379]|8[0-35-9]|2[0-249]|[36][05]|5[57]|7[157]|0[15])|4(?:1[015]|4[47]|3[013]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
+    '160' => '(?:8(?:3(?:41|89|3[01468]|0[14689]|1[169]|6[168]|5[18]|2[1457]|7[457])|5(?:01|57|65|1[0-259]|4[379]|2[0-249]|3[05]|7[157]|8[0-36-9])|4(?:50|72|1[015]|2[0239]|4[47]|3[013]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|2[0158]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
-    '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:1[25]|4[013]|7[57]|2[279]|5[16-8]|8[0357]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
-    '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[13])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|6[156]|5[35])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
+    '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[02468]|5[045]|6[689]|3[68]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|0[27]|2[12]|8[48]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[57])|0(?:22|55|0[15])|953))',
+    '163' => '(?:(?:0(?:5(?:7[056]|5[7-9]|6[069])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|9(?:43|3[89])|4(?:56|78)|2[67]8|7[27]7)|1(?:3(?:50|6[38]|4[59]|8[28]|7[18])|0(?:71|6[156]|5[35])|4(?:55|70|8[08])|5(?:88|3[37]))|8(?:6(?:02|26|80|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
     '164' => '(?:8(?:5(?:[67]7|30|41|2[25]|8[58]|5[05]|0[13-5]|1[12])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[24])|7(?:01|25)))',
     '165' => '(?:8(?:555|780))',
-    '166' => '(?:8(?:5(?:20|55|3[13589]|6[5-7]|4[025]|0[1-36]|8[58]|7[078])|6(?:01|10)))',
-    '167' => '(?:8(?:5(?:[24]0|85|7[78]|3[34]|6[07]|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
-    '168' => '(?:8(?:5(?:[67]0|85|3[03]|5[058]|0[1-468]|2[05]|1[0-2])|6(?:01|2[06]|[18][16])|081))',
+    '166' => '(?:85(?:20|88|3[13589]|6[5-7]|4[025]|0[1-36]|7[078]))',
+    '167' => '(?:8(?:5(?:[246]0|34|85|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
+    '168' => '(?:8(?:5(?:[67]0|5[058]|0[1-468]|2[05]|1[0-2]|3[035])|6(?:01|2[06]|[18][16])|081))',
     '169' => '(?:8(?:5(?:6[018]|2[0-25-7]|8[0568]|4[013]|3[0135]|0[37-9]|1[015-7]|7[078]|5[01568])|6(?:2[04]|5[056]|7[78]|0[1358]|1[0-36]|6[1468]|4[0458]|3[179])|0(?:50|77|1[12])|7(?:[01]1|22)|228|915))',
-    '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|7[067]|5[015-9]|6[0156]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|0[25]|[35][35])|0(?:55|73)|5(?:51|85))|6080))',
-    '171' => '(?:85(?:3[19]|7[027]|5[023578]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|8[0268]|0[1-37-9]))',
+    '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|6[0-256]|7[067]|5[015-9]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
+    '171' => '(?:85(?:5[23578]|3[19]|7[027]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|8[0268]|0[1-37-9]))',
     '173' => '(?:8(?:5(?:[06]1|30|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|66|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:30|88|5[058]|6[07]|2[0146]|0[15])|6(?:01|12|46|3[369]|8[068])|7(?:[01]1|3[079]|4[0134])|860|903))',
-    '175' => '(?:85(?:88|7[17]))',
+    '175' => '(?:85(?:71|88))',
     '176' => '(?:85(?:[46]0|85|1[0-2568]|2[1258]|3[013-6]|0[1-378]))',
-    '177' => '(?:85(?:[12]1|0[1-357-9]))',
-    '178' => '(?:8(?:5(?:11|55|67|0[12])|6(?:[68]6|01|24)))',
+    '177' => '(?:85(?:21|0[1-389]))',
+    '178' => '(?:8(?:5(?:11|67|0[12])|6(?:[68]6|01|24)))',
     '179' => '(?:8(?:9(?:0[134679]|1[014])|501))',
-    '180' => '(?:8(?:5(?:80|1[79]|7[17]|6[67]|3[138]|2[27]|5[05]|0[58])|6(?:29|60|3[03]|1[018]|0[28])|7(?:50|77)))',
+    '180' => '(?:8(?:5(?:66|80|1[79]|7[17]|3[138]|2[27]|0[58])|6(?:29|33|1[018]|0[28])|7(?:50|77)))',
     '181' => '(?:8(?:5(?:41|3[135]|7[17]|0[35]|8[5-8]|1[01578]|5[15]|2[0-28])|6(?:22|33|48|1[14]|0[18])|001))',
-    '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|86|0[12])|001))',
-    '183' => '(?:8(?:5(?:61|2[124-689]|1[1-46]|5[013]|3[0249]|0[12568]|4[0189])|70[1-35-7]))',
-    '184' => '(?:8(?:5(?:[34]3|22|67|95|8[158]|5[58]|7[57]|0[1-58]|1[01])|795))',
+    '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|86|0[12])|00[16]))',
+    '183' => '(?:8(?:5(?:61|2[124-689]|1[1-46]|5[013]|3[0249]|4[0189]|0[1256])|70[1-35-7]))',
+    '184' => '(?:8(?:5(?:[34]3|22|95|8[158]|5[58]|7[57]|0[1-58]|1[01])|795))',
     '185' => '(?:8(?:5(?:33|40|6[27]|0[126]|1[01])|601|795))',
     '186' => '(?:8(?:6(?:50|0[1-3]|1[19]|8[068]|6[68])|5(?:01|19|85)|79[78]|001))',
     '187' => '(?:8(?:5(?:40|0[2357]|3[13]|5[1358]|2[02]|6[07]|8[1578]|7[078]|1[0-28])|(?:61|70)1))',
     '188' => '(?:8(?:5(?:[58]5|11)|6(?:66|80)|701))',
-    '189' => '(?:85(?:[01]1|85|5[05]|2[01]))',
+    '189' => '(?:85(?:[01]1|20|85|5[05]))',
     '190' => '(?:(?:8(?:5(?:3[015-79]|5[013-578]|6[0-256]|8[1-3689]|0[135-9]|7[1-358]|1[013-9]|4[034]|2[0-28])|6(?:66|8[0168]))|129[2357]|0192))',
-    '191' => '(?:8(?:5(?:20|55|0[1-35-79]|1[0-2])|6(?:60|86)))',
-    '192' => '(?:(?:8(?:5(?:77|85|2[025]|6[28]|5[1368]|3[235-7]|1[0258]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-8])))',
+    '191' => '(?:8(?:5(?:20|0[1-35-79]|1[0-2])|6(?:60|86)))',
+    '192' => '(?:(?:8(?:5(?:77|85|2[025]|6[28]|5[1368]|3[235-7]|1[0258]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-7])))',
     '193' => '(?:(?:8(?:5(?:[57]0|33|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
     '194' => '(?:(?:8(?:5(?:77|1[015]|4[03]|0[23578]|8[0568]|5[0158]|2[07]|6[067]|3[038])|6(?:66|1[0-2]))|029[2-8]))',
     '195' => '(?:85(?:85|5[05]))',
     '196' => '(?:8(?:5(?:01|22|5[058]|8[58]|1[01])|6(?:[01]1|86|6[68])))',
     '197' => '(?:8(?:5(?:[01]1|55)|6(?:01|23)))',
-    '198' => '(?:8(?:5(?:31|55|77|2[25]|1[02]|8[58])|7(?:01|22|60|1[01])|6(?:[01]1|66)))',
+    '198' => '(?:8(?:5(?:31|55|77|2[25]|1[02]|8[58])|7(?:22|60|[01][01])|6(?:[018]1|55|66)))',
     '201' => '(?:8(?:5(?:[01]1|8[58])|6(?:01|48|86)))',
     '202' => '(?:85(?:20|85|5[58]))',
     '203' => '(?:8(?:5(?:[12]1|55|8[58])|601|739))',
     '204' => '(?:85(?:11|22|33|67|5[58]|8[589]))',
-    '205' => '(?:8(?:6(?:6[06]|0[13467])|5(?:11|55|0[13])))',
-    '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|6[167]|0[235]|5[05]|1[125])|6(?:[68]6|11|0[12])))',
+    '205' => '(?:8(?:5(?:11|55|0[13])|6(?:60|0[13467])))',
+    '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|6[167]|0[235]|5[05]|1[125])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
-    '208' => '(?:85(?:85|0[1-3]|5[05]))',
+    '208' => '(?:85(?:[58]5|0[1-3]))',
     '210' => '(?:(?:8(?:5(?:2[1-3]|5[027-9]|6[0259]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
     '211' => '(?:8(?:5(?:[2-4]0|66|5[058]|7[07]|8[58]|1[01]|0[125])|6(?:01|1[19]|6[68])))',
     '212' => '(?:8(?:5(?:44|90|1[13]|0[1-389]|6[03467]|8[1-489]|2[05]|7[0267]|5[1457]|3[01])|602))',
@@ -211,7 +211,7 @@ our %ZIP_TABLE = (
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
     '230' => '(?:8(?:5(?:11|85|7[17]|0[14]|5[05])|6(?:[01]1|[68]6|2[38])|765))',
-    '231' => '(?:8(?:5(?:[25]0|42|6[26]|3[46]|8[08])|4(?:[38]4|45|61|1[19]|7[078])|3(?:3[018]|2[0134]|1[0145])|6(?:16|82|5[04])|0(?:80|0[18])|711|966))',
+    '231' => '(?:8(?:5(?:[25]0|42|6[26]|3[46]|8[08])|4(?:[38]4|45|61|1[19]|7[078])|3(?:3[018]|2[0134]|1[0145])|6(?:16|82|5[04])|0(?:80|0[18])|7(?:11|7[12])|966))',
     '232' => '(?:8(?:5(?:15|31|76|8[057]|5[58])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:[58]8|2[23]|0[15]))',
@@ -219,9 +219,9 @@ our %ZIP_TABLE = (
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
     '238' => '(?:(?:8(?:5(?:8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|8[58]|5[08])|68[68]))',
-    '240' => '(?:(?:8(?:5(?:[02]1|[45]0|15)|612)|019[2-8]))',
+    '240' => '(?:(?:8(?:5(?:[02]1|[45]0|15)|612)|019[235-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
-    '242' => '(?:8(?:5(?:[07]7|[58]5)|6(?:01|10)))',
+    '242' => '(?:8(?:5(?:[07]7|[58]5|39)|6(?:01|10)))',
     '243' => '(?:(?:0(?:4(?:60|9[2-8]|8[3-689])|19[23578]|29[278]|392)|8(?:5(?:21|33|88|5[015]|7[17]|1[01]|0[15])|60[14])))',
     '244' => '(?:8(?:5(?:10|0[1-3]|6[69]|7[17]|2[28]|5[058]|8[589]|3[039])|601))',
     '245' => '(?:85(?:[16]0|01|42|89|5[0358]|7[57]))',
@@ -238,7 +238,7 @@ our %ZIP_TABLE = (
     '256' => '(?:8510)',
     '257' => '(?:8(?:5(?:11|33|55|66|2[23]|0[12]|8[4-68])|686))',
     '258' => '(?:(?:85(?:11|85|3[38]|0[168])|0195))',
-    '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|39[26])|0(?:19[2-46-8]|39[2356])))',
+    '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|39[26])|0(?:1(?:9[2-46-8]|8[01])|39[2356])))',
     '260' => '(?:8(?:6(?:0[13467]|2[0-24-79]|5[46]|4[2578]|1[0-3689]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|2[134]|8[0568]|7[257]|3[2458]|1[0-68]|0[1-35-9]|5[0-24-9]|6[02-7])|7(?:3[03]|1[02357]|2[02]|0[1-37])))',
     '261' => '(?:8(?:5(?:66|75|3[03]|5[245]|4[45]|1[235]|2[0-2]|0[1-378]|8[125-8])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:36|55|0[2-468]|1[0-2])|7(?:10|33)))',
@@ -248,7 +248,7 @@ our %ZIP_TABLE = (
     '266' => '(?:8(?:550|733))',
     '270' => '(?:(?:1(?:3(?:8[1-357]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:9[2578]|8[08])|39[23])|8(?:5(?:[0-2]1|55)|625)|019[248]))',
     '271' => '(?:8(?:5(?:01|22|33|8[058]|1[0158]|5[0157]|6[02-4])|6(?:66|72|2[05])))',
-    '272' => '(?:85(?:[47]3|01|3[38]|[58][058]|2[02]|1[1-368]|6[01]))',
+    '272' => '(?:85(?:[47]3|01|3[38]|[58][058]|2[02]|1[0-368]|6[01]))',
     '273' => '(?:(?:8(?:5(?:7[04]|3[03]|2[0-3]|8[458]|1[0-25]|6[067]|4[023]|5[01568]|0[1-58])|6(?:01|27)|733)|019[2357]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:[01]1|28|33|60|8[058]|7[25-7])|6(?:[01]1|66)))',
@@ -259,7 +259,7 @@ our %ZIP_TABLE = (
     '282' => '(?:86(?:02|10))',
     '283' => '(?:(?:8(?:5(?:[01]1|55|88)|650)|0195))',
     '284' => '(?:8555)',
-    '285' => '(?:8(?:5(?:50|67|0[1-3]|8[568]|2[0-2]|1[01])|6(?:19|5[05])|765))',
+    '285' => '(?:8(?:5(?:50|67|8[568]|0[1-39]|2[0-2]|1[01])|6(?:19|5[05])|765))',
     '286' => '(?:(?:85(?:[02]1|8[58])|029[23]))',
     '287' => '(?:(?:8(?:5(?:[58]5|10|0[1-3])|601)|0292))',
     '288' => '(?:8601)',
@@ -294,7 +294,7 @@ our %ZIP_TABLE = (
     '318' => '(?:85[01]1)',
     '319' => '(?:(?:1(?:1(?:9[24-6]|8[48])|29[235]|59[23]|393)|0(?:29[2-5]|39[3-57]|19[28])|2692|3595))',
     '320' => '(?:8(?:5(?:5[015]|3[0-38]|6[0467]|8[058]|4[013]|7[07]|0[1-3578]|2[1-358]|1[0-2457])|6(?:20|55|68|1[018]|0[17]|8[068])))',
-    '321' => '(?:(?:3(?:29[235-8]|49[378]|39[25]|59[58])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|1(?:29[237]|49[23]|692)|4(?:39[23568]|29[235])|85(?:[58]5|0[25])))',
+    '321' => '(?:(?:3(?:29[235-8]|49[378]|39[25]|59[58])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[23]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86))|[01]192))',
     '324' => '(?:(?:8(?:5(?:01|85|1[06]|5[015])|6(?:25|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
@@ -431,7 +431,7 @@ our %ZIP_TABLE = (
     '457' => '(?:8(?:5(?:[48]5|3[0-35]|[05][158]|2[02]|1[0-25]|7[07]|6[067])|71[12]))',
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
-    '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|0[1-3689]|3[0-35-8]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|0[1-35-8]|1[125-7]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-69]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|1[0-68]|4[0135]|7[04578]|0[13-9]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
+    '460' => '(?:8(?:4(?:7[02357]|1[125-7]|0[1-8]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-69]|6[0-28]|4[014578])|6(?:90|7[0-2489]|8[1-9]|6[035-9]|0[1-3689]|3[0-35-8]|5[0135-7]|2[013568]|1[013-9])|5(?:5[01589]|[23][0-58]|8[05-8]|1[0-68]|4[0135]|7[04578]|0[13-9]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
     '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[1256])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|8[058]|6[67]|1[12]|5[0458]|0[589])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:8(?:2(?:8[0-278]|3[0249]|5[0-256]|6[0236]|4[0157]|2[126-8]|1[0-8]|7[08]|0[1-79])|5(?:44|2[1-3]|6[05-7]|0[14]|5[01568]|7[4578]|3[15]|1[1-37]|8[023568])|3(?:3[348]|0[148]|1[018]|8[389]|4[16]|2[1-47]|5[035])|4(?:75|80|1[015]|0[1-38]|4[18])|6(?:1[018]|0[12]|8[08])|79[136-8]))',
+    '530' => '(?:8(?:2(?:8[0-278]|3[0249]|5[0-256]|6[0236]|4[0157]|2[126-8]|1[0-8]|7[08]|0[1-79])|5(?:44|2[1-3]|6[05-7]|5[0-2568]|0[14]|7[4578]|3[15]|1[1-37]|8[023568])|3(?:3[348]|0[148]|1[018]|8[389]|4[16]|2[1-47]|5[035])|4(?:75|80|1[015]|0[1-38]|4[18])|6(?:1[018]|0[12]|8[08])|79[136-8]))',
     '531' => '(?:(?:8(?:5(?:26|67|88|0[1-3]|5[58]|1[01])|787)|6053))',
     '532' => '(?:8(?:5(?:35|60|77|2[045]|8[58]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -517,12 +517,12 @@ our %ZIP_TABLE = (
     '545' => '(?:85(?:[01]1|22|33|45|5[05]|8[56]))',
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
-    '549' => '(?:8585)',
+    '549' => '(?:85(?:11|22|85))',
     '550' => '(?:8(?:5(?:10|38|6[67]|2[27]|8[05]|7[0578]|5[0258]|0[1-35])|6(?:59|60)))',
     '551' => '(?:85[05]1)',
     '552' => '(?:85(?:01|10))',
     '553' => '(?:8(?:5(?:67|1[1-3]|0[13]|5[0358]|8[58])|739))',
-    '554' => '(?:85(?:[01]1|[58][58]))',
+    '554' => '(?:85(?:[01]1|8[58]))',
     '555' => '(?:85(?:55|0[12]))',
     '556' => '(?:8(?:5(?:85|0[13]|5[058]|1[0256])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
@@ -556,10 +556,10 @@ our %ZIP_TABLE = (
     '586' => '(?:85(?:[58]5|01|77|2[18]|1[15]))',
     '587' => '(?:85(?:55|8[56]))',
     '589' => '(?:85(?:11|85|0[12]))',
-    '590' => '(?:(?:8(?:5(?:[34]0|03|77|2[27-9]|1[17]|6[07]|8[58]|5[01])|686)|0(?:4(?:9[3-6]|8[12])|592)))',
+    '590' => '(?:(?:8(?:5(?:[34]0|03|77|2[27-9]|6[07]|8[58]|1[157]|5[01])|686)|0(?:4(?:9[3-6]|8[12])|592)))',
     '591' => '(?:85(?:11|55|0[125]))',
     '592' => '(?:8585)',
-    '594' => '(?:(?:8(?:50[12]|686)|1198))',
+    '594' => '(?:(?:8(?:50[12]|686)|119[28]))',
     '595' => '(?:8(?:5(?:85|5[58])|6(?:50|86)))',
     '596' => '(?:8(?:6(?:[25]4|86)|510))',
     '597' => '(?:8(?:5(?:22|43|55|8[58]|0[12]|1[15])|686))',
@@ -608,7 +608,7 @@ our %ZIP_TABLE = (
     '644' => '(?:(?:86(?:55|86)|1292))',
     '645' => '(?:8511)',
     '646' => '(?:(?:8(?:5(?:[01]1|8[058]|4[45]|5[08])|660)|(?:02|1[14])92))',
-    '647' => '(?:(?:1(?:294|792)|8555))',
+    '647' => '(?:(?:1(?:294|792)|855[15]))',
     '648' => '(?:(?:0(?:2(?:8\d|9[2-8])|198|392)|85(?:41|85)))',
     '649' => '(?:(?:6(?:49[2-4]|59[235]|[126]92)|(?:[04]1|35)92|219[2358]|719[245]))',
     '650' => '(?:8(?:5(?:43|1[015]|5[01589]|2[0-258]|6[057]|3[0369]|7[015-7]|8[04-689]|0[1-35])|6(?:[68][06]|7[07])|7(?:87|94)))',
@@ -634,7 +634,7 @@ our %ZIP_TABLE = (
     '670' => '(?:8(?:5(?:43|3[03]|7[057]|8[058]|6[67]|5[0458]|2[024]|1[017]|0[1256])|6(?:7[057]|5[25]|6[068]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:59[2358]|19[238]|28[08])|419[23]|0295))',
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
-    '673' => '(?:(?:8(?:5(?:11|58|85)|6[68]6)|1(?:49[3-5]|192|395)|0[45]92))',
+    '673' => '(?:(?:8(?:5(?:11|85)|6[68]6)|1(?:49[3-5]|192|395)|0[45]92))',
     '674' => '(?:8(?:5(?:[58]5|01)|686))',
     '675' => '(?:(?:8(?:5(?:01|22|33|66|77|88|1[019]|5[58])|68[68])|01(?:9[2-468]|8[0-68])|1(?:3(?:80|95)|192|297)|239[358]))',
     '676' => '(?:8(?:5(?:01|33|40|58|66|85|1[03])|6(?:55|7[07]|8[68])))',
@@ -865,20 +865,20 @@ our %ZIP_TABLE = (
     '906' => '(?:(?:0[256]92|8[56]01))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
     '910' => '(?:(?:8(?:5(?:3[0235-9]|8\d|4[013-58]|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|2[0-8]|7[15689])|6(?:22|30|6[0568]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|3[56])92|419[35-8]))',
-    '911' => '(?:8(?:5(?:[03]1|[14]0|88|5[58])|601))',
+    '911' => '(?:8(?:5(?:[03]1|[14]0|5[58])|601))',
     '912' => '(?:(?:8(?:5(?:[58]5|24|40|67)|6[68]6)|0292))',
     '913' => '(?:8(?:5(?:[01]1|33|55|77|8[58])|611))',
     '914' => '(?:(?:8(?:5(?:[14]0|24|67|5[058]|8[05]|0[12])|6(?:09|66|8[68]))|019[258]))',
     '915' => '(?:(?:8(?:5(?:[58]5|01|3[03]|1[01])|666)|0292|1195))',
     '916' => '(?:(?:8(?:5(?:67|5[058]|8[58]|1[05]|0[1578])|6(?:[468]6|01))|0(?:29[235]|[14]92)|1198))',
-    '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[2378]|39[38]|198)))',
+    '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|39[38]|198)))',
     '918' => '(?:8(?:5(?:4[03]|5[0568]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|0[1-358]|8[03568])|68[168]))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:7[03578]|0[1-9]|4[0134]|2[0-25]|3[0135-9]|1[0-3578]|5[0-8]|6[0135-8]|8[035-8])|6(?:2[0-356]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|8[01568]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[137]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:5[025]|4[14689]|1[0-2578]|3[0-269]|7[1-9]|2[02-79]|0[15-8]|8[0-47-9]|6[0-2457])|6(?:01|50|3[079]|1[126]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[2-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|1[156]|4[2-46]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
-    '924' => '(?:8(?:5(?:01|22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]))',
+    '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]))',
     '925' => '(?:(?:8(?:5(?:30|85|6[67]|5[05]|0[1-3568]|2[15]|1[01])|6(?:[12]0|09|88))|0(?:19[38]|392|498)))',
     '926' => '(?:(?:8(?:5(?:[013]1|20|66|4[015]|8[568]|5[058])|6(?:[68]6|42|50|1[01]|0[1-359]))|0(?:29[23]|192)))',
     '927' => '(?:(?:0(?:49[235]|29[23]|695)|129[57]|219[23]|8601))',
@@ -889,7 +889,7 @@ our %ZIP_TABLE = (
     '932' => '(?:(?:8(?:5(?:33|40|75|1[0-258]|5[0158]|6[27]|8[58]|0[1-358]|2[0258])|611)|0(?:39[23568]|19[38]|29[28])))',
     '933' => '(?:(?:8(?:5(?:4[03]|6[367]|8[58]|1[01568]|0[126-8]|3[0-3578]|5[08]|2[035-8])|6(?:[28]8|66|0[1-356]|1[01])|7(?:77|88))|0(?:39[235-7]|19[235]|29[235])))',
     '934' => '(?:8(?:5(?:22|77|6[78]|3[14]|[58][058]|0[12]|1[15])|6(?:[15]1|8[68])))',
-    '935' => '(?:(?:8(?:5(?:[01]1|55|3[15])|6(?:01|86))|0492))',
+    '935' => '(?:(?:8(?:5(?:01|55|3[15])|6(?:01|86))|0492))',
     '936' => '(?:8(?:5(?:36|77|0[127]|[58][58])|6(?:86|0[18])))',
     '937' => '(?:8(?:5(?:[58]5|03|11|6[67])|6(?:01|60|78)))',
     '938' => '(?:(?:8(?:6(?:1[0-3]|0[12])|5(?:[58]5|0[25]))|029[23]))',
@@ -919,11 +919,11 @@ our %ZIP_TABLE = (
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
     '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|8[569]|7[05-7]|6[014-68]|3[07]|0[129]|1[01])|292|794)|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|0(?:19[25-8]|296)|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
     '964' => '(?:(?:8(?:5(?:[67]7|01|58)|601)|0[23]92))',
-    '965' => '(?:8(?:5(?:[34]0|67|[58][058]|2[02]|0[1-356]|7[07]|1[016])|6(?:[01]1|78)))',
+    '965' => '(?:8(?:5(?:[34]0|67|8[058]|2[02]|0[1-356]|7[07]|5[08]|1[016])|6(?:[01]1|78)))',
     '966' => '(?:(?:0(?:19[2-4]|485)|8601))',
     '967' => '(?:8501)',
     '968' => '(?:0498)',
-    '969' => '(?:(?:1(?:1(?:8[0168]|9[235])|[2-46]92|79[23])|6(?:19[256]|59[23]|292|495)|3(?:39[2356]|59[2-4]|192)|0(?:29[26]|[34]92|197)|4495))',
+    '969' => '(?:(?:1(?:1(?:8[0168]|9[235])|[2-46]92|79[23])|3(?:39[2356]|59[2-4]|[14]92)|6(?:19[256]|59[23]|292|495)|0(?:29[26]|[34]92|197)|4495))',
     '970' => '(?:(?:8(?:6(?:[23]5|[48]6|11)|5(?:[05]1|1[16]))|119[2-4]))',
     '971' => '(?:8615)',
     '972' => '(?:85(?:01|55))',
